@@ -10,7 +10,7 @@ use Carp;
 
 
 
-our $VERSION = "0.029";
+our $VERSION = "0.030";
 
 =head1 NAME
 
@@ -488,15 +488,15 @@ use Text::ParseWords;
 use constant STEP => 0.8;	# TODO: Optimal value?
 
 my %magstep =
-  ( # "xx-small"	=> 1.0*STEP*STEP*STEP,
-     "x-small"	=> 1.0*STEP*STEP,
-     "small"	=> 1.0*STEP,
+  ( "xx-small"	=> 1.0*STEP*STEP*STEP,
+    "x-small"	=> 1.0*STEP*STEP,
+    "small"	=> 1.0*STEP,
     "smaller"	=> 1.0*STEP,
-    # "medium"	=> 1.0,
-    # "large"	=> 1.0/STEP,
+    "medium"	=> 1.0,
+    "large"	=> 1.0/STEP,
     "larger"	=> 1.0/STEP,
-    # "x-large"	=> 1.0/(STEP*STEP),
-    # "xx-large"  => 1.0/(STEP*STEP*STEP),
+    "x-large"	=> 1.0/(STEP*STEP),
+    "xx-large"  => 1.0/(STEP*STEP*STEP),
   );
 
 sub set_markup {
@@ -569,24 +569,24 @@ sub set_markup {
 		    if ( $try_size->($v) ) {
 			#ok
 		    }
-		    elsif ( $v =~ /(\d+(?:\.\d+)?)pt$/ ) {
+		    elsif ( $v =~ /^(\d+(?:\.\d+)?)pt$/ ) {
 			$fsiz = $self->{_pango}
 			  ? $1 * PANGO_DEVICE_UNITS / PDF_DEVICE_UNITS
 			  : $1;
 			# warn("fsiz \"$v\" -> $fsiz\n");
 		    }
-		    elsif ( $v =~ /\d+(?:\.\d+)?$/ ) {
+		    elsif ( $v =~ /^\d+(?:\.\d+)?$/ ) {
 			$fsiz = $self->{_pango}
 			  ? $v * PANGO_DEVICE_UNITS / PDF_DEVICE_UNITS / PANGO_SCALE
 			  : $v;
 			# warn("fsiz \"$v\" -> $fsiz\n");
 		    }
-		    elsif ( $v =~ /(\d+(?:\.\d+)?)\%$/ ) {
+		    elsif ( $v =~ /^(\d+(?:\.\d+)?)\%$/ ) {
 			$fsiz *= $1 / 100;
 			# warn("fsiz \"$v\" -> $fsiz\n");
 		    }
 		    else {
-			carp("Invalid size: $v\n");
+			carp("Invalid size: \"$v\"\n");
 		    }
 		}
 
@@ -705,7 +705,7 @@ sub set_markup {
 	    }
 
 	    else {
-		carp("Invalid span markup: $k\n");
+		carp("Invalid span markup: \"$k\"\n");
 	    }
 	}
     };
@@ -798,7 +798,7 @@ sub set_markup {
 	    }
 
 	    else {
-		carp("Invalid markup: $k\n");
+		carp("Invalid markup: \"$k\"\n");
 	    }
 	}
 
@@ -1289,7 +1289,7 @@ sub set_alignment {
 	$self->{_alignment} = lc $align;
     }
     else {
-	croak("Invalid alignment: $align");
+	croak("Invalid alignment: \"$align\"");
     }
     delete( $self->{_bbcache} );
 }
